@@ -1,25 +1,7 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 
 #include "filterwidget.h"
@@ -69,6 +51,11 @@ void FilterWidget::clear()
     ui->filterEdit->clear();
 }
 
+void FilterWidget::setShowDoneTasks(bool show)
+{
+    m_model->setShowDoneTasks(show);
+}
+
 void FilterWidget::setShowFutureTasks(bool show)
 {
     m_model->setShowFutureTasks(show);
@@ -76,7 +63,7 @@ void FilterWidget::setShowFutureTasks(bool show)
 
 void FilterWidget::onTextChanged(const QString &text)
 {
-    m_model->setFilterFixedString(text);
+    m_model->setFilterRegularExpression(QRegularExpression::escape(text));
 }
 
 void FilterWidget::onSortTypeChanged(int index)
