@@ -15,16 +15,16 @@
 #include <KCalCore/Todo>
 #include <KCalCore/ICalFormat>
 
-#include <AkonadiCore/Akonadi/Collection>
-#include <AkonadiCore/Akonadi/TransactionSequence>
+#include <Akonadi/Collection>
+#include <Akonadi/TransactionSequence>
 #include "akonadi/akonadicollectionfetchjobinterface.h"
 #include "akonadi/akonadiitemfetchjobinterface.h"
 #include "akonadi/akonadistorage.h"
 #include "akonadi/akonadiserializer.h"
 
-#include <AkonadiCore/Akonadi/CollectionFetchJob>
-#include <AkonadiCore/Akonadi/ItemFetchJob>
-#include <AkonadiCore/Akonadi/ItemFetchScope>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 
 #include <QProcess>
 
@@ -179,7 +179,7 @@ private:
             //qDebug() << item.id() << it.key();
             auto todo = item.payload<KCalCore::Todo::Ptr>();
             QVERIFY(todo);
-            const auto contextUids = todo->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyContextList()).split(',', QString::SkipEmptyParts);
+            const auto contextUids = todo->customProperty(Serializer::customPropertyAppName(), Serializer::customPropertyContextList()).split(',', Qt::SkipEmptyParts);
             QStringList contextNames;
             std::transform(contextUids.cbegin(), contextUids.cend(), std::back_inserter(contextNames), [this](const QString &uid) { return m_contextTodos.value(uid); });
             contextNames.sort();
